@@ -12,21 +12,23 @@
 #
 import os
 import sys
+
 import django
-sys.path.insert(0, os.path.abspath('../..'))
-os.environ['DJANGO_SETTINGS_MODULE'] = '_django.settings'
+
+sys.path.insert(0, os.path.abspath("../.."))
+os.environ["DJANGO_SETTINGS_MODULE"] = "_django.settings"
 django.setup()
 
 
 # -- Project information -----------------------------------------------------
 
-project = 'Django Kubernetes Manager'
-copyright = '2020, Bradley Reimers'
-author = 'Bradley Reimers'
-master_doc = 'index'
+project = "Django Kubernetes Manager"
+copyright = "2020, Bradley Reimers"
+author = "Bradley Reimers"
+master_doc = "index"
 
 # The full version, including alpha/beta/rc tags
-release = '0.1.0'
+release = "0.1.0"
 
 
 # -- General configuration ---------------------------------------------------
@@ -34,11 +36,10 @@ release = '0.1.0'
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.doctest', 'sphinx.ext.coverage'
-]
+extensions = ["sphinx.ext.autodoc", "sphinx.ext.doctest", "sphinx.ext.coverage", "sphinxcontrib.httpdomain", "sphinxcontrib.openapi"]
 
 # Add any paths that contain templates here, relative to this directory.
-templates_path = ['_templates']
+templates_path = ["_templates"]
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
@@ -57,4 +58,4 @@ html_theme = "sphinx_rtd_theme"
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
+html_static_path = ["_static"]
